# -*- coding: utf-8 -*-
# Generated by Django 1.11.12 on 2018-04-08 20:12
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wooey', '0037_repeat_migration_spg_sp_script_version'),
    ]

    operations = [
        migrations.AlterField(
            model_name='wooeyjob',
            name='status',
            field=models.CharField(choices=[('completed', 'Completed'), ('deleted', 'Deleted'), ('FAILURE', 'Failed'), ('running', 'Running'), ('submitted', 'Submitted')], default='submitted', max_length=255),
        ),
    ]
