# -*- coding: utf-8 -*-
# Generated by Django 1.11.11 on 2018-03-28 09:50
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('wooey', '0036_make_scriptparameter_jsonfield'),
    ]

    operations = [
        # These migrations were covered by 0029->0032 but for some reason Django wants to
        # repeat them. This should be a pointless change.
        migrations.AlterField(
            model_name='scriptparametergroup',
            name='script_version',
            field=models.ManyToManyField(to='wooey.ScriptVersion'),
        ),
        migrations.AlterField(
            model_name='scriptparser',
            name='script_version',
            field=models.ManyToManyField(to='wooey.ScriptVersion'),
        ),
    ]
