# -*- coding: utf-8 -*-
# Generated by Django 1.11.11 on 2018-03-28 09:48
from __future__ import unicode_literals

from django.db import migrations, models
import jsonfield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('wooey', '0035_populate-jsonfield'),
    ]

    operations = [
        migrations.AlterField(
            model_name='scriptparameter',
            name='default',
            field=jsonfield.fields.JSONCharField(blank=True, max_length=255, null=True),
        ),
    ]
