{% extends "wooey/base.html" %}
{% load i18n %}
{% load wooey_tags %}

{% block left_sidebar %}{% endblock left_sidebar %}
{% block center_content_class %}col-md-12 col-xs-12{% endblock center_content_class %}
{% block center_content %}
<div class="row"><div class="col-md-12 col-xs-12">404</div></div>
{% endblock center_content %}
